@@ -22,11 +22,27 @@
 #include <string.h>
 #include <glib.h>
 
-#include <libintl.h>
 #include "../config.h"
-#define _(String) gettext (String)
+#include <glib/gi18n-lib.h>
 #include "../include/liststore.h"
 
+/**
+ * SECTION: liststore
+ * @short_description: Parse, store and prepare data
+ * @title: liststore
+ * @section_id: liststore
+ * @include: include/liststore.h
+ */
+
+/**
+ * get_liststore:
+ *
+ * Extract documentation strings from .ini file, and fill a
+ * @GtkListStore with it.
+ *
+ * Returns: a @GtkListStore containing documentation strings for the
+ * GNU commands supported by Tutoterm
+ */
 GtkListStore*
 get_liststore ()
 {
