@@ -18,10 +18,9 @@
  */
 
 #include <gtk/gtk.h>
-
-#include <libintl.h>
 #include "../config.h"
-#define _(String) gettext (String)
+#include <glib/gi18n-lib.h>
+#include <locale.h>
 #include "../include/tutoterm.h"
 
 int
@@ -29,6 +28,7 @@ main (int argc, char **argv)
 {
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (PACKAGE);
   
   GtkApplication *app;
